Glossary
--------

.. glossary::

    Accumulator
      A variable used in a loop to add up or accumulate a result.

    Loop Counter
      A variable used in a loop to count the number of times something happened. We initialize
      a counter to zero then increment the counter each time we want to "count" something.

    Decrement
      To decrease the value of a variable (often by one).

    Initialize
      To give an initial value to a variable that will be updated.

    Increment
      To increase the value of a variable (often by one).

    Infinite Loop
      A loop in which the terminating condition is never satisfied or for which there is no
      terminating condition.

    Iteration
      One repeated execution of a set of statements using either a function that calls itself or a loop.


.. dragndrop:: iteration_glossary_one
    :practice: T
    :feedback: If you're stuck, look above for the definitions of these terms! Try again.
    :match_1: accumulator|||A variable used in a loop to add up or accumulate a result.
    :match_2: loop counter|||A variable used in a loop to count the number of times something happened. We initialize a counter to zero and then increment the counter each time we want to "count" something.
    :match_3: decrement|||To decrease the value of a variable (often by one).
    :match_4: increment|||To increase the value of a variable (often by one).

    Match the terms on the left with their defintions on the right.

.. dragndrop:: iteration_glossary_two
    :practice: T
    :feedback: If you're stuck, look above for the definitions of these terms! Try again.
    :match_1: initialize|||To give an initial value to a variable that will be updated.
    :match_2: infinite loop|||A loop in which the terminating condition is never satisfied or for which there is no terminating condition.
    :match_3: iteration|||One repeated execution of a set of statements using either a function that calls itself or a loop.

    Match the terms on the left with their defintions on the right.
